InitOptions class

Additional options for initializing the Aptabase SDK.

Constructors

InitOptions({String? host, Duration tickDuration = _kDefaultTickDuration, int batchLength = _kMaxBatchLength, bool printDebugMessages = false})
const

Properties

batchLength → int
final
hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
printDebugMessages → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tickDuration → Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited