StorageManager class abstract

Implementers

Constructors

StorageManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEvent(String key, String event) Future<void>
deleteEvents(Set<String> keys) Future<void>
getItems(int length) Future<Iterable<MapEntry<String, String>>>
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited