SystemInfo class

System information about the current device.

Properties

appVersion ↔ String
getter/setter pair
buildNumber ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ String
getter/setter pair
osName ↔ String
getter/setter pair
osVersion ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

get() → Future<SystemInfo>
Returns the system information for the current device.
getOsInfoForTesting({Future<({String name, String version})> resolveOsInfo(DeviceInfoPlugin)?, ({String name, String version}) fallbackOsInfo()?}) → Future<({String name, String version})>